/* 
 * Copyright (C) 2003 the xine project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: noskin_window.h,v 1.2 2004/04/09 18:07:52 guenter Exp $
 *
 * standard, non-skinned main window
 */

#ifndef HAVE_NOSKIN_WINDOW_H
#define HAVE_NOSKIN_WINDOW_H

#include <glib.h>

void noskin_main_init (void) ;

void noskin_main_close (void);

#endif
